# organizze-api-sdk
Specification for the Organizze API described in [https://github.com/organizze/api-doc](https://github.com/organizze/api-doc)

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.0
- Package version: 1.0.0
- Generator version: 7.17.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.9+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import organizze_api
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import organizze_api
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import organizze_api
from organizze_api.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://api.organizze.com.br/rest/v2
# See configuration.py for a list of all supported configuration parameters.
configuration = organizze_api.Configuration(
    host = "https://api.organizze.com.br/rest/v2"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure HTTP basic authorization: basicAuth
configuration = organizze_api.Configuration(
    username = os.environ["USERNAME"],
    password = os.environ["PASSWORD"]
)

# Configure API key authorization: userAgent
configuration.api_key['userAgent'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['userAgent'] = 'Bearer'


# Enter a context with an instance of the API client
with organizze_api.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = organizze_api.BankAccountsApi(api_client)
    bank_account = organizze_api.BankAccount() # BankAccount | 

    try:
        # Create Bank Account
        api_response = api_instance.create_bank_account(bank_account)
        print("The response of BankAccountsApi->create_bank_account:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling BankAccountsApi->create_bank_account: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.organizze.com.br/rest/v2*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*BankAccountsApi* | [**create_bank_account**](docs/BankAccountsApi.md#create_bank_account) | **POST** /accounts | Create Bank Account
*BankAccountsApi* | [**delete_bank_account**](docs/BankAccountsApi.md#delete_bank_account) | **DELETE** /accounts/{bankAccountID} | Delete Bank Account
*BankAccountsApi* | [**list_bank_accounts**](docs/BankAccountsApi.md#list_bank_accounts) | **GET** /accounts | List Bank Accounts
*BankAccountsApi* | [**read_bank_account**](docs/BankAccountsApi.md#read_bank_account) | **GET** /accounts/{bankAccountID} | Read Account
*BankAccountsApi* | [**update_bank_account**](docs/BankAccountsApi.md#update_bank_account) | **PUT** /accounts/{bankAccountID} | Update Bank Account
*BudgetsApi* | [**list_annual_budgets**](docs/BudgetsApi.md#list_annual_budgets) | **GET** /budgets/{year} | Get Annual Budgets
*BudgetsApi* | [**list_current_month_budgets**](docs/BudgetsApi.md#list_current_month_budgets) | **GET** /budgets | Get Current Month Budgets
*BudgetsApi* | [**list_monthly_budgets**](docs/BudgetsApi.md#list_monthly_budgets) | **GET** /budgets/{year}/{month} | Get Monthly Budgets
*CategoriesApi* | [**create_category**](docs/CategoriesApi.md#create_category) | **POST** /categories | Create Category
*CategoriesApi* | [**delete_category**](docs/CategoriesApi.md#delete_category) | **DELETE** /categories/{categoryID} | Delete Category
*CategoriesApi* | [**list_categories**](docs/CategoriesApi.md#list_categories) | **GET** /categories | List Categories
*CategoriesApi* | [**read_category**](docs/CategoriesApi.md#read_category) | **GET** /categories/{categoryID} | Read Category
*CategoriesApi* | [**update_category**](docs/CategoriesApi.md#update_category) | **PUT** /categories/{categoryID} | Update Category
*CreditCardsApi* | [**create_credit_card**](docs/CreditCardsApi.md#create_credit_card) | **POST** /credit_cards | Create Credit Card
*CreditCardsApi* | [**delete_credit_card**](docs/CreditCardsApi.md#delete_credit_card) | **DELETE** /credit_cards/{creditCardID} | Delete Credit Card
*CreditCardsApi* | [**list_credit_card_invoice_payments**](docs/CreditCardsApi.md#list_credit_card_invoice_payments) | **GET** /credit_cards/{creditCardID}/invoices/{creditCardInvoiceID}/payments | List Credit Card Invoice Payments
*CreditCardsApi* | [**list_credit_card_invoices**](docs/CreditCardsApi.md#list_credit_card_invoices) | **GET** /credit_cards/{creditCardID}/invoices | List Credit Card Invoices
*CreditCardsApi* | [**list_credit_cards**](docs/CreditCardsApi.md#list_credit_cards) | **GET** /credit_cards | List Credit Cards
*CreditCardsApi* | [**read_credit_card**](docs/CreditCardsApi.md#read_credit_card) | **GET** /credit_cards/{creditCardID} | Read Credit Card
*CreditCardsApi* | [**read_credit_card_invoice**](docs/CreditCardsApi.md#read_credit_card_invoice) | **GET** /credit_cards/{creditCardID}/invoices/{creditCardInvoiceID} | Read Credit Card Invoice
*CreditCardsApi* | [**update_credit_card**](docs/CreditCardsApi.md#update_credit_card) | **PUT** /credit_cards/{creditCardID} | Update Credit Card
*TransactionsApi* | [**create_transaction**](docs/TransactionsApi.md#create_transaction) | **POST** /transactions | Create Transaction
*TransactionsApi* | [**delete_transaction**](docs/TransactionsApi.md#delete_transaction) | **DELETE** /transactions/{transactionID} | Delete Transaction
*TransactionsApi* | [**list_transactions**](docs/TransactionsApi.md#list_transactions) | **GET** /transactions | List Transactions
*TransactionsApi* | [**read_transaction**](docs/TransactionsApi.md#read_transaction) | **GET** /transactions/{transactionID} | Read Transaction
*TransactionsApi* | [**update_transaction**](docs/TransactionsApi.md#update_transaction) | **PUT** /transactions/{transactionID} | Update Transaction
*UsersApi* | [**list_users**](docs/UsersApi.md#list_users) | **GET** /users | List Users
*UsersApi* | [**read_user**](docs/UsersApi.md#read_user) | **GET** /users/{userID} | Read User


## Documentation For Models

 - [BankAccount](docs/BankAccount.md)
 - [Budget](docs/Budget.md)
 - [Category](docs/Category.md)
 - [CreateTransactionRequest](docs/CreateTransactionRequest.md)
 - [CreditCard](docs/CreditCard.md)
 - [CreditCardInvoice](docs/CreditCardInvoice.md)
 - [CreditCardInvoiceFull](docs/CreditCardInvoiceFull.md)
 - [DeleteTransactionRequest](docs/DeleteTransactionRequest.md)
 - [FailedAuthentication](docs/FailedAuthentication.md)
 - [InstallmentTransaction](docs/InstallmentTransaction.md)
 - [InstallmentTransactionAllOfInstallmentsAttributes](docs/InstallmentTransactionAllOfInstallmentsAttributes.md)
 - [NotFound](docs/NotFound.md)
 - [RecurringTransaction](docs/RecurringTransaction.md)
 - [RecurringTransactionAllOfRecurrenceAttributes](docs/RecurringTransactionAllOfRecurrenceAttributes.md)
 - [Transaction](docs/Transaction.md)
 - [UpdateTransactionRequest](docs/UpdateTransactionRequest.md)
 - [User](docs/User.md)
 - [ValidationError](docs/ValidationError.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="basicAuth"></a>
### basicAuth

- **Type**: HTTP basic authentication

<a id="userAgent"></a>
### userAgent

- **Type**: API key
- **API key parameter name**: User-Agent
- **Location**: HTTP header


## Author




